@@ -216,6 +216,7 @@ class Cursor(DBAPICursor):
         self.connection = connection
         self._data = None
         self._query_columns_description = None
+        self._is_metadata_updated = False
         self._description = None
         self._query_id = None
         self._batch = list()
@@ -326,9 +327,7 @@ class Cursor(DBAPICursor):
         client.executeStatement(self._query_id)
 
         # _logger.info("getting result metadata")
-        buffer = client.getResultMetadata(self._query_id)
-        buffer = BytesIO(buffer)
-        self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
+        self.update_mete_data()
         # _logger.info("finished populating metadata", self._query_id)
         return self._query_id
 
@@ -336,6 +335,11 @@ class Cursor(DBAPICursor):
         # _logger.info("fetch returning the rowcount from e6x itself")
         return self._rowcount
 
+    def update_mete_data(self):
+        buffer = self.connection.client.getResultMetadata(self._query_id)
+        buffer = BytesIO(buffer)
+        self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
+
     def _fetch_more(self):
         # _logger.info("fetching batch")
         batch_size = self._arraysize
@@ -364,7 +368,9 @@ class Cursor(DBAPICursor):
         # _logger.debug("fetching next batch from e6data")
         client = self.connection.client
         buffer = client.getNextResultBatch(self._query_id)
-
+        if not self._is_metadata_updated:
+            self.update_mete_data()
+            self._is_metadata_updated = True
         if not buffer:
             return None
         buffer = BytesIO(buffer)
@@ -401,6 +407,9 @@ class Cursor(DBAPICursor):
         rows_to_return = []
         client = self.connection.client
         buffer = client.getNextResultRow(self._query_id)
+        if not self._is_metadata_updated:
+            self.update_mete_data()
+            self._is_metadata_updated = True
         if not buffer:
             return None
         buffer = BytesIO(buffer)
